shithub: libvpx

Download patch

ref: f5d3be7e96e7852144120e62168dae8bca081fa2
parent: 4641e750bac4f6e315df512d5baf5df195760dc0
parent: 5d2f6baac3f3f1ed34d75cdcebcd1daaf86b3fb3
author: Johann <johannkoenig@google.com>
date: Tue May 21 11:44:52 EDT 2013

Merge "thumb: Adjust the conversion of the position independent switch"

--- a/build/make/thumb.pm
+++ b/build/make/thumb.pm
@@ -53,9 +53,10 @@
 
     # Convert a conditional addition to the pc register into a series of
     # instructions. This converts "addlt pc, pc, r3, lsl #2" into
-    # "ittt lt", "addlt.w r12, pc, #10", "addlt.w r12, r12, r3, lsl #2",
-    # "movlt.n pc, r12". This assumes that r12 is free at this point.
-    s/^(\s*)addlt(\s+)pc,\s*pc,\s*(\w+),\s*lsl\s*#(\d+)/$1ittt$2lt\n$1addlt.w$2r12, pc, #10\n$1addlt.w$2r12, r12, $3, lsl #$4\n$1movlt.n$2pc, r12/g;
+    # "itttt lt", "movlt.n r12, pc", "addlt.w r12, #12",
+    # "addlt.w r12, r12, r3, lsl #2", "movlt.n pc, r12".
+    # This assumes that r12 is free at this point.
+    s/^(\s*)addlt(\s+)pc,\s*pc,\s*(\w+),\s*lsl\s*#(\d+)/$1itttt$2lt\n$1movlt.n$2r12, pc\n$1addlt.w$2r12, #12\n$1addlt.w$2r12, r12, $3, lsl #$4\n$1movlt.n$2pc, r12/g;
 
     # Convert "mov pc, lr" into "bx lr", since the former only works
     # for switching from arm to thumb (and only in armv7), but not
--